
from .memory import MemoryRepo
from .mongo import MongoRepo
from .sqlalchemy import SQLRepo
from .rest import RESTRepo
from .csv import CSVFileRepo
from .json import JSONDirectoryRepo